@@ -1,5 +1,5 @@
 """
 A simple CLI to deal with the problems. Can be easily replaced by your own.
 """
-from .arguments import parse_arguments, create_default_argument_parser
+from .arguments import create_default_argument_parser, parse_arguments
 from .cli import cli
